/****************************************************************************
 *                                                                          
 * Title:   Load Arbitrary data in Normal mode
 *
 * Purpose: This example shows how to load Arbitrary data to Channel 1 DAC
 *          data and Channel 2 volatile data in normal mode.
 *
 ****************************************************************************/

#include <ansi_c.h>
#include "rssiam.h"

/*** Macros & definitions ***************************************************/

#define CHECKERR( fCal ) \
    { \
        fCalStartTime = clock();\
        error = (fCal);\
        status = error;\
        printf(" Line %ld (%ld ms): %s\n", __LINE__,\
            (fCalTime = (clock() - fCalStartTime)), #fCal);\
        if (error != VI_SUCCESS)\
            {\
            rssiam_error_message (io, error, error_message);\
            printf("\tFunction Call Status: 0x%08X, %s\n", error, error_message);\
            rssiam_error_query(io, &error, error_message);\
            printf("\tInstrument Error: 0x%X, %s\n", error, error_message);\
            }\
    }

#define RESOURCE_NAME   "am" // "USB::0xAAD::0x5::100011" // Resource name

/*** Main *******************************************************************/

int main (int argc, char *argv[])
{
    ViStatus    error               = VI_SUCCESS,
                status              = VI_SUCCESS;
    clock_t     fCalTime            = 0,
                fCalStartTime       = 0;
    ViChar      error_message[256];
    ViSession   io;

    ViReal64    volatile_data[1024],
                resolution          = 0.0,
                grad                = 0.0,
                rad                 = 0.0;
    ViInt16     DAC_data[1024],
                samples             = 0,
                max                 = 0,
                min                 = 0,
                i                   = 0;

    /* Define remote connection parameters (as default values) */

    ViBoolean   IDQuery             = VI_TRUE,
                resetDevice         = VI_TRUE;
    ViRsrc      resourceName        = RESOURCE_NAME;

    CHECKERR (rssiam_init (resourceName, IDQuery, resetDevice, &io));

    printf (

    "\n --- Load Arb Data -----------------------------------------------------\n\n"
    "\t - Normal mode\n\n"
    "\t CH1:\n\n"
    "\t - DAC Data\n\n"
    "\t CH2:\n\n"
    "\t - Volatile Data\n"
    "\n ------------------------------------------------------------------------\n\n"

    );

    /* Calculate Arb data (sine and cosine wave) */

    samples     = 1024;
    max         = 16383;                // DAC max
    min         = -16383;               // DAC min
    resolution  = (2.0 / (max - min));  // Volatile data range is from -1.0 to 1.0

    for (i = 0; i < samples; i++)
        {
        grad = (360.0 / (float)(samples)) * (float)i;
        rad = grad * (3.141592654/180.0);
        DAC_data[i] = (sin(rad)) / resolution;
        volatile_data[i] = cos(rad);
        }

    /* --- CH1 Function --- */
    CHECKERR (rssiam_outpChannel (io, RSSIAM_CH1));
    CHECKERR (rssiam_funcShap (io, RSSIAM_OUTPUT_FUNC_USER));

    /* --- CH2 Function --- */
    CHECKERR (rssiam_outpChannel (io, RSSIAM_CH2));
    CHECKERR (rssiam_funcShap (io, RSSIAM_OUTPUT_FUNC_USER));

    /* --- CH1 Arb Data --- */
    CHECKERR (rssiam_outpChannel (io, RSSIAM_CH1));
    CHECKERR (rssiam_dataDacVolatile (io, samples, DAC_data));

    /* --- CH2 Arb Data --- */
    CHECKERR (rssiam_outpChannel (io, RSSIAM_CH2));
    CHECKERR (rssiam_dataVolatile (io, samples, volatile_data));

    /* Set Arb parameters */
    CHECKERR (rssiam_dataArbRateMode (io, RSSIAM_ARB_RATE_MODE_NORMAL));
    CHECKERR (rssiam_freq (io, 1000.0));

    /* --- CH1 State --- */
    CHECKERR (rssiam_outpChannel (io, RSSIAM_CH1));
    CHECKERR (rssiam_outpSetup (io, RSSIAM_OUTPUT_SETUP_ON));

    /* --- CH2 State --- */
    CHECKERR (rssiam_outpChannel (io, RSSIAM_CH2));
    CHECKERR (rssiam_outpSetup (io, RSSIAM_OUTPUT_SETUP_ON));

    printf ("\n");

    CHECKERR (rssiam_close (io));

    return 0;
}
